@@ -54,13 +54,14 @@ func (oi *Os) getDistroIcon(distro string) string {
 		"almalinux":           "\uF31D",
 		"almalinux9":          "\uF31D",
 		"alpine":              "\uF300",
+		"android":             "\uF17b",
 		"aosc":                "\uF301",
 		"arch":                "\uF303",
 		"centos":              "\uF304",
 		"coreos":              "\uF305",
 		"debian":              "\uF306",
+		"deepin":              "\uF321",
 		"devuan":              "\uF307",
-		"raspbian":            "\uF315",
 		"elementary":          "\uF309",
 		"fedora":              "\uF30a",
 		"gentoo":              "\uF30d",
@@ -70,12 +71,12 @@ func (oi *Os) getDistroIcon(distro string) string {
 		"nixos":               "\uF313",
 		"opensuse":            "\uF314",
 		"opensuse-tumbleweed": "\uF314",
+		"raspbian":            "\uF315",
 		"redhat":              "\uF316",
 		"rocky":               "\uF32B",
 		"sabayon":             "\uF317",
 		"slackware":           "\uF319",
 		"ubuntu":              "\uF31b",
-		"android":             "\uf17b",
 	}
 
 	if icon, ok := iconMap[distro]; ok {
